@@ -16,15 +16,26 @@
 
 #define FLINT_USES_FENV 1
 
-#define FLINT_HAVE_FFT_SMALL
+#define FLINT_HAVE_FFT_SMALL 1
 
 #define FLINT_KNOW_STRONG_ORDER 0
 
-/* Just set to some reasonable threshold */
-#define FLINT_FFT_SMALL_THRESHOLD 600
+#define FLINT_BITS 64
+#define FLINT_LONG_LONG 0
+
+/* #undef FLINT_STATIC_BUILD */
+
+/* NOTE: Here we assume this is how it works. */
+#if defined(_MSC_VER) || defined(__MINGW32__) || defined(__MINGW64__)
+# define HAVE__ALIGNED_MALLOC 1
+#else
+# define HAVE_ALIGNED_ALLOC 1
+#endif
 
 #ifdef _MSC_VER
-# if defined(FLINT_BUILD_DLL)
+# if defined(FLINT_STATIC_BUILD)
+#  define FLINT_DLL
+# elif defined(FLINT_BUILD_DLL)
 #  define FLINT_DLL __declspec(dllexport)
 # else
 #  define FLINT_DLL __declspec(dllimport)
